@@ -20,9 +20,6 @@ use num_traits::FromPrimitive;
 pub use self::state::{LaneState, Merge, State};
 pub use self::types::*;
 
-#[cfg(feature = "wasm")]
-pub const WASM_BINARY: &[u8] = include_bytes!(env!("WASM_BINARY"));
-
 wasm_trampoline!(Actor);
 
 mod state;
